==> mlrun-1.6.3rc12-py3-none-any.whl: mlrun/common/schemas/__init__.py <==
# Copyright 2023 Iguazio
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# flake8: noqa  - this is until we take care of the F401 violations with respect to __all__ & sphinx

from .artifact import (
    Artifact,
    ArtifactCategories,
    ArtifactIdentifier,
    ArtifactMetadata,
    ArtifactsFormat,
    ArtifactSpec,
)
from .auth import (
    AuthInfo,
    AuthorizationAction,
    AuthorizationResourceTypes,
    AuthorizationVerificationInput,
    Credentials,
    ProjectsRole,
)
from .background_task import (
    BackgroundTask,
    BackgroundTaskList,
    BackgroundTaskMetadata,
    BackgroundTaskSpec,
    BackgroundTaskState,
    BackgroundTaskStatus,
)
from .client_spec import ClientSpec
from .clusterization_spec import (
    ClusterizationSpec,
    WaitForChiefToReachOnlineStateFeatureFlag,
)
from .common import ImageBuilder
from .constants import (
    APIStates,
    ClusterizationRole,
    DeletionStrategy,
    FeatureStorePartitionByField,
    HeaderNames,
    LogsCollectorMode,
    OrderType,
    PatchMode,
    RunPartitionByField,
    SortField,
)
from .datastore_profile import DatastoreProfile
from .events import (
    AuthSecretEventActions,
    EventClientKinds,
    EventsModes,
    SecretEventActions,
)
from .feature_store import (
    EntitiesOutput,
    Entity,
    EntityListOutput,
    EntityRecord,
    Feature,
    FeatureListOutput,
    FeatureRecord,
    FeatureSet,
    FeatureSetDigestOutput,
    FeatureSetDigestSpec,
    FeatureSetIngestInput,
    FeatureSetIngestOutput,
    FeatureSetRecord,
    FeatureSetsOutput,
    FeatureSetSpec,
    FeatureSetsTagsOutput,
    FeaturesOutput,
    FeatureVector,
    FeatureVectorRecord,
    FeatureVectorsOutput,
    FeatureVectorsTagsOutput,
)
from .frontend_spec import (
    AuthenticationFeatureFlag,
    FeatureFlags,
    FrontendSpec,
    NuclioStreamsFeatureFlag,
    PreemptionNodesFeatureFlag,
    ProjectMembershipFeatureFlag,
)
from .function import FunctionState, PreemptionModes, SecurityContextEnrichmentModes
from .http import HTTPSessionRetryMode
from .hub import (
    HubCatalog,
    HubItem,
    HubObjectMetadata,
    HubSource,
    HubSourceSpec,
    IndexedHubSource,
    last_source_index,
)
from .k8s import NodeSelectorOperator, Resources, ResourceSpec
from .memory_reports import MostCommonObjectTypesReport, ObjectTypeReport
from .model_monitoring import (
    DriftStatus,
    EndpointType,
    EndpointUID,
    EventFieldType,
    EventKeyMetrics,
    Features,
    FeatureSetFeatures,
    FeatureValues,
    GrafanaColumn,
    GrafanaDataPoint,
    GrafanaNumberColumn,
    GrafanaStringColumn,
    GrafanaTable,
    GrafanaTimeSeriesTarget,
    ModelEndpoint,
    ModelEndpointList,
    ModelEndpointMetadata,
    ModelEndpointSpec,
    ModelEndpointStatus,
    ModelMonitoringMode,
    ModelMonitoringStoreKinds,
    MonitoringFunctionNames,
    TimeSeriesTarget,
)
from .notification import (
    Notification,
    NotificationKind,
    NotificationSeverity,
    NotificationStatus,
    SetNotificationRequest,
)
from .object import ObjectKind, ObjectMetadata, ObjectSpec, ObjectStatus
from .pipeline import PipelinesFormat, PipelinesOutput, PipelinesPagination
from .project import (
    IguazioProject,
    Project,
    ProjectDesiredState,
    ProjectMetadata,
    ProjectOwner,
    ProjectsFormat,
    ProjectsOutput,
    ProjectSpec,
    ProjectState,
    ProjectStatus,
    ProjectSummariesOutput,
    ProjectSummary,
)
from .regex import RegexMatchModes
from .runs import RunIdentifier
from .runtime_resource import (
    GroupedByJobRuntimeResourcesOutput,
    GroupedByProjectRuntimeResourcesOutput,
    KindRuntimeResources,
    ListRuntimeResourcesGroupByField,
    RuntimeResource,
    RuntimeResources,
    RuntimeResourcesOutput,
)
from .schedule import (
    ScheduleCronTrigger,
    ScheduleIdentifier,
    ScheduleInput,
    ScheduleKinds,
    ScheduleOutput,
    ScheduleRecord,
    SchedulesOutput,
    ScheduleUpdate,
)
from .secret import (
    AuthSecretData,
    SecretKeysData,
    SecretProviderName,
    SecretsData,
    UserSecretCreationRequest,
)
from .tag import Tag, TagObjects
from .workflow import (
    GetWorkflowResponse,
    WorkflowRequest,
    WorkflowResponse,
    WorkflowSpec,
)

==> mlrun-1.6.4rc6-py3-none-any.whl: mlrun/common/schemas/__init__.py <==
# Copyright 2023 Iguazio
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# flake8: noqa  - this is until we take care of the F401 violations with respect to __all__ & sphinx

from .artifact import (
    Artifact,
    ArtifactCategories,
    ArtifactIdentifier,
    ArtifactMetadata,
    ArtifactsFormat,
    ArtifactSpec,
)
from .auth import (
    AuthInfo,
    AuthorizationAction,
    AuthorizationResourceTypes,
    AuthorizationVerificationInput,
    Credentials,
    ProjectsRole,
)
from .background_task import (
    BackgroundTask,
    BackgroundTaskList,
    BackgroundTaskMetadata,
    BackgroundTaskSpec,
    BackgroundTaskState,
    BackgroundTaskStatus,
)
from .client_spec import ClientSpec
from .clusterization_spec import (
    ClusterizationSpec,
    WaitForChiefToReachOnlineStateFeatureFlag,
)
from .common import ImageBuilder
from .constants import (
    APIStates,
    ClusterizationRole,
    DeletionStrategy,
    FeatureStorePartitionByField,
    HeaderNames,
    LogsCollectorMode,
    OrderType,
    PatchMode,
    RunPartitionByField,
    SortField,
)
from .datastore_profile import DatastoreProfile
from .events import (
    AuthSecretEventActions,
    EventClientKinds,
    EventsModes,
    SecretEventActions,
)
from .feature_store import (
    EntitiesOutput,
    Entity,
    EntityListOutput,
    EntityRecord,
    Feature,
    FeatureListOutput,
    FeatureRecord,
    FeatureSet,
    FeatureSetDigestOutput,
    FeatureSetDigestSpec,
    FeatureSetIngestInput,
    FeatureSetIngestOutput,
    FeatureSetRecord,
    FeatureSetsOutput,
    FeatureSetSpec,
    FeatureSetsTagsOutput,
    FeaturesOutput,
    FeatureVector,
    FeatureVectorRecord,
    FeatureVectorsOutput,
    FeatureVectorsTagsOutput,
)
from .frontend_spec import (
    AuthenticationFeatureFlag,
    FeatureFlags,
    FrontendSpec,
    NuclioStreamsFeatureFlag,
    PreemptionNodesFeatureFlag,
    ProjectMembershipFeatureFlag,
)
from .function import FunctionState, PreemptionModes, SecurityContextEnrichmentModes
from .http import HTTPSessionRetryMode
from .hub import (
    HubCatalog,
    HubItem,
    HubObjectMetadata,
    HubSource,
    HubSourceSpec,
    IndexedHubSource,
    last_source_index,
)
from .k8s import NodeSelectorOperator, Resources, ResourceSpec
from .memory_reports import MostCommonObjectTypesReport, ObjectTypeReport
from .model_monitoring import (
    DriftStatus,
    EndpointType,
    EndpointUID,
    EventFieldType,
    EventKeyMetrics,
    Features,
    FeatureSetFeatures,
    FeatureValues,
    GrafanaColumn,
    GrafanaDataPoint,
    GrafanaNumberColumn,
    GrafanaStringColumn,
    GrafanaTable,
    GrafanaTimeSeriesTarget,
    ModelEndpoint,
    ModelEndpointList,
    ModelEndpointMetadata,
    ModelEndpointSpec,
    ModelEndpointStatus,
    ModelMonitoringMode,
    ModelMonitoringStoreKinds,
    MonitoringFunctionNames,
    TimeSeriesTarget,
)
from .notification import (
    Notification,
    NotificationKind,
    NotificationSeverity,
    NotificationStatus,
    SetNotificationRequest,
)
from .object import ObjectKind, ObjectMetadata, ObjectSpec, ObjectStatus
from .pipeline import PipelinesFormat, PipelinesOutput, PipelinesPagination
from .project import (
    IguazioProject,
    Project,
    ProjectDesiredState,
    ProjectMetadata,
    ProjectOwner,
    ProjectsFormat,
    ProjectsOutput,
    ProjectSpec,
    ProjectState,
    ProjectStatus,
    ProjectSummariesOutput,
    ProjectSummary,
)
from .regex import RegexMatchModes
from .runs import RunIdentifier, RunsFormat
from .runtime_resource import (
    GroupedByJobRuntimeResourcesOutput,
    GroupedByProjectRuntimeResourcesOutput,
    KindRuntimeResources,
    ListRuntimeResourcesGroupByField,
    RuntimeResource,
    RuntimeResources,
    RuntimeResourcesOutput,
)
from .schedule import (
    ScheduleCronTrigger,
    ScheduleIdentifier,
    ScheduleInput,
    ScheduleKinds,
    ScheduleOutput,
    ScheduleRecord,
    SchedulesOutput,
    ScheduleUpdate,
)
from .secret import (
    AuthSecretData,
    SecretKeysData,
    SecretProviderName,
    SecretsData,
    UserSecretCreationRequest,
)
from .tag import Tag, TagObjects
from .workflow import (
    GetWorkflowResponse,
    WorkflowRequest,
    WorkflowResponse,
    WorkflowSpec,
)
